V0.2 ractor adapter runtime for the dactor actor framework.
Bridges dactor’s Actor/Handler<M>/ActorRef<A> API with ractor’s
single-message-type ractor::Actor trait using type-erased dispatch.
Structs
- Ractor
Actor Ref - A dactor
ActorRefbacked by a ractorActorRef. - Ractor
Runtime - A dactor v0.2 runtime backed by ractor.
- Ractor
System Actor Refs - References to the native ractor system actors spawned by the runtime.
- Spawn
Options - Options for spawning an actor, including the inbound interceptor pipeline.
Options for spawning an actor. Use
..Default::default()to future-proof against new fields. - System
Actor Pool - Round-robin pool of ractor actors.
Enums
- System
Actor Handle - Handle to a system actor that may be a single actor or a pool.