pub struct SpawnOptions {
pub interceptors: Vec<Box<dyn InboundInterceptor>>,
pub mailbox: MailboxConfig,
}Expand description
Options for spawning an actor, including the inbound interceptor pipeline.
Options for spawning an actor. Use ..Default::default() to future-proof
against new fields.
Fields
interceptors: Vec<Box<dyn InboundInterceptor>>Inbound interceptors to attach to the actor.
mailbox: MailboxConfigMailbox capacity configuration.
Mailbox capacity configuration.
When Bounded, a bounded mpsc channel is
placed in front of the ractor actor to enforce backpressure.