Module runtime

Module runtime 

V0.2 ractor adapter runtime for the dactor actor framework.

Bridges dactor’s Actor/Handler<M>/ActorRef<A> API with ractor’s single-message-type ractor::Actor trait using type-erased dispatch.

Structs

RactorActorRef
A dactor ActorRef backed by a ractor ActorRef.
RactorRuntime
A dactor v0.2 runtime backed by ractor.
RactorSystemActorRefs
References to the native ractor system actors spawned by the runtime.
SpawnOptions
Options for spawning an actor, including the inbound interceptor pipeline. Options for spawning an actor. Use ..Default::default() to future-proof against new fields.